--[[----------------------------------------------------------------------------

EcoSeeUser.lua
EcoSee user account management

--------------------------------------------------------------------------------

ADOBE SYSTEMS INCORPORATED
 Copyright 2007 Adobe Systems Incorporated
 All Rights Reserved.

NOTICE: Adobe permits you to use, modify, and distribute this file in accordance
with the terms of the Adobe license agreement accompanying it. If you have received
this file from a source other than Adobe, then your use, modification, or distribution
of it requires the prior written permission of Adobe.

------------------------------------------------------------------------------]]

	-- Lightroom SDK
local LrBinding = import 'LrBinding'
local LrDialogs = import 'LrDialogs'
local LrFunctionContext = import 'LrFunctionContext'

local prefs = import 'LrPrefs'.prefsForPlugin()


--============================================================================--

EcoSeeUser = {}

--------------------------------------------------------------------------------

local function storedCredentialsAreValid()

	return prefs.token -- and prefs.nsid and prefs.username and prefs.fullname

end

--------------------------------------------------------------------------------

local function notLoggedIn( propertyTable )

	propertyTable.token = nil
	
	-- prefs.nsid = nil
	-- prefs.username = nil
	-- prefs.fullname = nil
	prefs.postKey = nil
	prefs.uploadURL = nil
	prefs.token = nil

	propertyTable.accountStatus = LOC "$$$/EcoSee/AccountStatus/NotLoggedIn=This plugin must have a valid Post Key & URL before it can be used."
	propertyTable.loginButtonTitle = LOC "$$$/EcoSee/LoginButton/NotLoggedIn=Enter Key"
	propertyTable.loginButtonEnabled = true
	propertyTable.validAccount = false

end

--------------------------------------------------------------------------------

local doingLogin = false

function EcoSeeUser.login( propertyTable )

	if doingLogin then return end
	doingLogin = true

	LrFunctionContext.postAsyncTaskWithContext( 'Validate',
	function( context )

		-- Clear any existing login info.
	
		notLoggedIn( propertyTable )

		propertyTable.accountStatus = LOC "$$$/EcoSee/AccountStatus/LoggingIn=Validating..."
		propertyTable.loginButtonEnabled = false
		
		-- Make sure login is valid when done, or is marked as invalid.
		
		context:addCleanupHandler( function()

			doingLogin = false

			if not storedCredentialsAreValid() then
				notLoggedIn( propertyTable )
			end
			
			-- Hrm. New API doesn't make it easy to show what operation failed.
			-- LrDialogs.message( LOC "$$$/EcoSee/LoginFailed=Failed to connect to EcoSee" )

		end )
		
		-- Make sure we have an Post key.
		
		EcoSeeAPI.getPostKeyAndURL()

		-- Show request for authentication dialog.
	
		-- local authRequestDialogResult = LrDialogs.confirm(
		-- 			LOC "$$$/EcoSee/AuthRequestDialog/Message=Lightroom needs your permission to upload images to your EcoSee powered site.",
		-- 			LOC "$$$/EcoSee/AuthRequestDialog/HelpText=If you click Authorize, you will be taken to a web page in your web browser where you can log in. When you're finished, return to Lightroom to complete the authorization.",
		-- 			LOC "$$$/EcoSee/AuthRequestDialog/AuthButtonText=Authorize",
		-- 			LOC "$$$/LrDialogs/Cancel=Cancel" )
		-- 	
		-- 		if authRequestDialogResult == 'cancel' then
		-- 			return
		-- 		end
	
		-- Request the frob that we need for authentication.
		
		propertyTable.accountStatus = LOC "$$$/EcoSee/AccountStatus/WaitingForEcoSee=Waiting for response from server..."

		require 'EcoSeeAPI'
		-- local frob = EcoSeeAPI.openAuthUrl()
	
		-- local waitForAuthDialogResult = LrDialogs.confirm(
		-- 	LOC "$$$/EcoSee/WaitForAuthDialog/Message=Return to this window once you've authorized Lightroom on your site.",
		-- 	LOC "$$$/EcoSee/WaitForAuthDialog/HelpText=Once you've granted permission for Lightroom (in your web browser), click the Done button below.",
		-- 	LOC "$$$/EcoSee/WaitForAuthDialog/DoneButtonText=Done",
		-- 	LOC "$$$/LrDialogs/Cancel=Cancel" )
		-- 	
		-- if waitForAuthDialogResult == 'cancel' then
		-- 	return
		-- end
	
		-- User has OK'd authentication. Get the user info.
		
		-- propertyTable.accountStatus = LOC "$$$/EcoSee/AccountStatus/WaitingForEcoSee=Waiting for response..."

		local data = EcoSeeAPI.callRestmode{ mode = 'validate', frob = frob }
		
		-- Now we can read the EcoSee user credentials. Save off to prefs.
	
		-- local auth = assert( data.auth )
	
		-- prefs.nsid = auth.user.nsid
		-- prefs.username = auth.user.username
		-- prefs.fullname = auth.user.fullname
		-- prefs.token = auth.token._value
		-- propertyTable.token = prefs.token
		
			prefs.token = 'OK'
			propertyTable.token = 'OK'
		
	end )

end

--------------------------------------------------------------------------------

function EcoSeeUser.verifyLogin( propertyTable )

	-- Observe changes to prefs and update status message accordingly.

	local function updateStatus()
	
		if storedCredentialsAreValid() then
			-- local displayUserName = prefs.fullname
			-- if not displayUserName or #displayUserName == 0 then
				-- displayUserName = prefs.username
			-- end
			-- propertyTable.accountStatus = LOC( "$$$/EcoSee/AccountStatus/LoggedIn=Logged in as ^1", displayUserName )
			propertyTable.accountStatus = LOC "$$$/EcoSee/AccountStatus/LoggedIn=Ready to upload"
			propertyTable.loginButtonTitle = LOC "$$$/EcoSee/LoginButton/LoggedIn=Change Key"
			propertyTable.loginButtonEnabled = true
			propertyTable.LR_canExport = true
		else
			notLoggedIn( propertyTable )
		end
	
	end

	propertyTable:addObserver( 'token', updateStatus )
	updateStatus()
	
end
